@@ -121,6 +121,14 @@ test_that("min_char is calculated correctly, including empty strings.", {
   expect_identical(input, correct)
 })
 
+test_that("min_char with a multibyte character does not throw an error.", {
+  data <- c("a", "ab", "abc", "Coleophora asteris M\x9fhl.")
+  #correct <- as.integer(1)
+  #input <- min_char(data)
+  #expect_identical(input, correct)
+  expect_error(min_char(data), NA)
+})
+
 test_that("max_char is calculated correctly, including empty strings.", {
   data<-c("a", "ab", "abc", "")
   correct <- as.integer(3)
@@ -128,6 +136,14 @@ test_that("max_char is calculated correctly, including empty strings.", {
   expect_identical(input, correct)
 })
 
+test_that("max_char with a multibyte character does not throw an error.", {
+  data <- c("a", "ab", "abc", "Coleophora asteris M\x9fhl.")
+  #correct <- as.integer(3)
+  #input <- max_char(data)
+  #expect_identical(input, correct)
+  expect_error(max_char(data, NA))
+})
+
 test_that("n_unique is calculated correctly.", {
   correct <- 4L
   data<-c("a", "ab", "abc", "")
